@@ -66,6 +66,9 @@ class ZeroShotClassificationExplainer(
         self.include_hypothesis = False
         self.attributions = []
 
+        self.internal_batch_size = None
+        self.n_steps = 50
+
     @property
     def word_attributions(self) -> dict:
         "Returns the word attributions for model and the text provided. Raises error if attributions not calculated."
@@ -235,6 +238,8 @@ class ZeroShotClassificationExplainer(
             ref_position_ids=self.ref_position_ids,
             token_type_ids=self.token_type_ids,
             ref_token_type_ids=self.ref_token_type_ids,
+            internal_batch_size=self.internal_batch_size,
+            n_steps=self.n_steps,
         )
         if self.include_hypothesis:
             lig.summarize()
@@ -249,6 +254,8 @@ class ZeroShotClassificationExplainer(
         embedding_type: int = 0,
         hypothesis_template="this text is about {} .",
         include_hypothesis: bool = False,
+        internal_batch_size: int = None,
+        n_steps: int = None,
     ) -> dict:
         """
         Calculates attribution for `text` using the model and
@@ -289,6 +296,11 @@ class ZeroShotClassificationExplainer(
         Returns:
             list: List of tuples containing words and their associated attribution scores.
         """
+
+        if n_steps:
+            self.n_steps = n_steps
+        if internal_batch_size:
+            self.internal_batch_size = internal_batch_size
         self.attributions = []
         self.pred_probs = []
         self.include_hypothesis = include_hypothesis
